extern gboolean
obex_object_push (const gchar *filename, const gchar *mimetype, const gchar *data, size_t len,
		  GCallback callback, gpointer cb_data);

extern void
obex_client_init (void);
